# hckr - Documentation Guide


## Writing and debugging documents locally
* Run this command to start ``doc`` developnment in local
```bash
make docs
```
this will build your docs and start them in localhost, eg. `http://127.0.0.1:63401/`

* After any changes you just have to save it and all of these changes will be reflected in the browser.

